@@ -156,7 +156,7 @@ def get_value_from_table(csv_file, col_referer=0, col_return=1,
 
     return _get_value_from_table
 
-def get_ids(model, fields, op='|'):
+def get_ids(model, fields, op='&'):
     """Return ``model`` which one or more ``fields`` matched column ``value``
    
     >>> 'partner_ids': Column(56, get_ids('res.partner.address', ['street', 'street2'], op='|'))
@@ -198,7 +198,7 @@ def get_ids(model, fields, op='|'):
     
     return _get_ids
 
-def get_id(model, fields, op='|'):
+def get_id(model, fields, op='&'):
     """Return ``model`` which one or more ``fields`` matched column ``value``
    
     >>> 'address_ids': (21, get_ids('res.partner', ['name']))
@@ -221,7 +221,7 @@ def get_id(model, fields, op='|'):
     
     return _get_id
 
-def get_objects(model, fields, op='|'):
+def get_objects(model, fields, op='&'):
     """Return ``model`` instance which ``fields``'s value matched ``value``
     
     >>> 'parent_name': Column(2, get_objects('res.partner.address', ['ref'])[0]['name'])
@@ -243,7 +243,7 @@ def get_objects(model, fields, op='|'):
 
     return _get_objects
 
-def get_field(model, fields, field, op='|'):
+def get_field(model, fields, field, op='&'):
     """Return ``model``'s ``field`` field which ``fields``'s value matched ``value``
     
     >>> 'parent_name': Column(2, get_field('res.partner.address', ['ref'], 'name')
@@ -268,7 +268,7 @@ def get_field(model, fields, field, op='|'):
 
     return _get_field
 
-def get_fields(model, fields, op='|'):
+def get_fields(model, fields, op='&'):
     """Return ``model`` instance which one or more ``fields`` matched column ``value``
     
     >>> 'parent_name': Column(2, get_fields('res.partner.address', ['ref']))
